# The barbatruc project

BARBATRUC is a training ground for CFD software training at Cerfacs.
The online documentation ca be found on [nitrox barbatruc page](http://open-source.pg.cerfacs.fr/barbatruc)


## Finite Differences Navier-Stokes.
The finite differences solver is a rewritten version of Lorena Barba's 12 steps to Navier-Stokes computations.

## Lattice Boltzmann  
The LBM solver is not ready for relaese. 
